Routine

Struct Routine 

pub struct Routine { /* private fields */ }
A handle for a routine running in the background

Returned by ThreadPool::subscribe. Dropping the handle:

  1. Calls unsubscribe (prevents future scheduling)
  2. Frees the closure and all captured state (immediately if the callback is not running, or deferred to the callback otherwise)