ThreadPool

Struct ThreadPool 

pub struct ThreadPool { /* private fields */ }
Thread pool for managing background tasks

The thread pool operates on “routines”, which are effectively closures called repeatedly by the thread pool until they return ControlFlow::Break.

To submit a task, pass it to ThreadPool::subscribe and store the received handle. Dropping the handle automatically unsubscribes and frees the routine.

Implementations

Source

impl ThreadPool

pub fn subscribe<F>(&self, func: F) -> Result<Routine, Error>
where F: FnMut() -> ControlFlow<()> + Send + 'static,

Run a task in a background thread

Returns a Routine. Dropping the handle automatically unsubscribes the routine and frees the closure (immediately if idle, or after the current callback invocation finishes).