pub struct Routine { /* private fields */ }Expand description
A handle for a routine running in the background
Returned by ThreadPool::subscribe. Dropping the handle:
- Calls
unsubscribe(prevents future scheduling) - Frees the closure and all captured state (immediately if the callback is not running, or deferred to the callback otherwise)